using System;
using ThinkGeo.MapSuite.Core;

namespace CSSamples.Samples.DataProviders
{
    public partial class CreateAnInMemoryFeatureLayer : System.Web.UI.Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            if (!Page.IsPostBack)
            {
                Map1.MapBackground.BackgroundBrush = new GeoSolidBrush(GeoColor.FromHtml("#E5E3DF"));
                Map1.CurrentExtent = new RectangleShape(-51, 121, 149, -13);
                Map1.MapUnit = GeographyUnit.DecimalDegree;

                InMemoryFeatureLayer inMemoryLayer = new InMemoryFeatureLayer();
                Feature feature = new Feature(BaseShape.CreateShapeFromWellKnownData("POLYGON((10 60,40 70,30 85, 10 60))"));
                // here you need to pass the id of feature as the key in the Collection
                inMemoryLayer.InternalFeatures.Add(feature.Id, feature);
                
                inMemoryLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle.FillSolidBrush.Color = GeoColor.FromArgb(100, GeoColor.StandardColors.RoyalBlue);
                inMemoryLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle.OutlinePen.Color = GeoColor.StandardColors.Blue;
                inMemoryLayer.ZoomLevelSet.ZoomLevel01.DefaultLineStyle.OuterPen = new GeoPen(GeoColor.FromArgb(200, GeoColor.StandardColors.Red), 5);
                inMemoryLayer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle.SymbolPen = new GeoPen(GeoColor.FromArgb(255, GeoColor.StandardColors.Green), 8);
                inMemoryLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
                Map1.DynamicOverlay.Layers.Add(inMemoryLayer);
                Map1.DynamicOverlay.TileType = ThinkGeo.MapSuite.WebEdition.TileType.SingleTile;
            }
        }

        protected void EraseBtn_Click(object sender, EventArgs e)
        {
            try
            {
                UpdateByErasingHighlights();
                //UpdatePanel1.Update();
            }
            catch
            {
                throw;
            }
        }

        public void UpdateByErasingHighlights()
        {
            try
            {
                bool redraw = false;

                InMemoryFeatureLayer layer = (InMemoryFeatureLayer)Map1.DynamicOverlay.Layers[0];
                if (layer.InternalFeatures.Count > 0)
                {
                    //layer.InternalFeatures.Clear();
                    for (var i = 0; i < layer.InternalFeatures.Count; i++)
                    {
                        layer.Open();
                        layer.FeatureSource.BeginTransaction();
                        layer.FeatureSource.DeleteFeature(layer.InternalFeatures[i].Id);
                        TransactionResult result = layer.FeatureSource.CommitTransaction();
                        layer.Close();
                    }
                    redraw = true;
                }
                layer = (InMemoryFeatureLayer)Map1.DynamicOverlay.Layers[0];
                if (layer.InternalFeatures.Count > 0)
                {
                    layer.InternalFeatures.Clear();
                    redraw = true;
                }
                if (redraw) Map1.DynamicOverlay.Redraw();
            }
            catch
            {
                throw;
            }
        }
    }
}
